@@ -197,13 +197,13 @@ int BuildCells( int noPisteVideo, CellArray_t * ca, int lastF )
 	int nrTS = Ifo_zero->vmgi_mat->vmg_nr_of_title_sets; /* Number of title sets */
 	int i,j,k;
 
-	DBG('b',fprintf(stderr,"%s: nrTS=%d noPisteVideo=%d\n", __FUNCTION__, nrTS, noPisteVideo ););
+	printf("nrTS=%d noPisteVideo=%d\n", nrTS, noPisteVideo );
 	for( k = 1; k <= nrTS; k++ ) {
 		ifo_handle_t * ifo = Ifo[k];
 		int vts_ttn, title_set_nr;
 		int nbChapter;
 
-		if( !ifo->vtsi_mat )	continue;
+		if( !ifo->vtsi_mat )	{ continue; }
 		DBG('b',fprintf(stderr,"VTS: %d PGCS: %d ifo: %p\n", k, ifo->vts_pgcit->nr_of_pgci_srp, ifo ););
 
 		vts_ttn = Ifo_zero->tt_srpt->title[noPisteVideo].vts_ttn; /* Title number within VTS */
@@ -248,7 +248,7 @@ DBG('b', fprintf(stderr,"title_set_nr=%d vts_ttn=%d pgcIndex=%d nbPgc=%d\n", tit
 	}
 	if( lastF )	UnSelectLastCell( ca );
 
-	DBG('b',fprintf(stderr,"NrCells: %d\n", ca->nbCells );
+	printf("NrCells: %d\n", ca->nbCells );
 	long long tSize = 0;
 	for( i = 0; i < ca->nbCells; i++ ) {
 		Cell_t * c = ca->cells + i;
@@ -262,8 +262,7 @@ DBG('b', fprintf(stderr,"title_set_nr=%d vts_ttn=%d pgcIndex=%d nbPgc=%d\n", tit
 		fprintf(stderr,"size: %s ", LLSize2Giga( size ) );
 		fprintf(stderr,"selected: %d\n", c->selected );
 	}
-	fprintf(stderr,"Total size: %s\n", LLSize2Giga( tSize ) );
-	);
+	printf("Total size: %s\n", LLSize2Giga( tSize ) );
 	return( 0 );
 }
 
