@@ -79,7 +79,7 @@ extern "C" {
 Cell_t *NewCell PROTO((CellArray_t *ca));
 TitleSet_t *NewTitleSet PROTO((TitleArray_t *ta));
 Vobu_t *NewVobu PROTO((VobuArray_t *va, uint32_t oldSector));
-int BuildCells PROTO((int noPisteVideo, CellArray_t *ca ));
+int BuildCells PROTO((int noPisteVideo, CellArray_t *ca, int lastF ));
 void FreeCellArray PROTO((CellArray_t *ca));
 int CountSelectedCells PROTO((CellArray_t *ca));
 void DumpVobus PROTO((Cell_t *c));
