@@ -182,6 +182,19 @@ pgc_t * pgc;
 	int cell = 0;
 	unsigned int total = 0;
 
+
+{
+	int j;
+
+	for( j = 0; j < pgc->nr_of_cells; j++ ) {
+		cell_playback_t * cell_playback = &pgc->cell_playback[j];
+		unsigned int secSize;
+
+		secSize	= cell_playback->last_sector - cell_playback->first_sector + 1;
+
+	}
+}
+
 	for( i = 0; i < pgc->nr_of_programs; i++ ) {
 		unsigned int sectors = 0;
 		int next;
@@ -190,12 +203,39 @@ pgc_t * pgc;
 			next = pgc->nr_of_cells + 1;
 		else
 			next = pgc->program_map[i + 1];
-		while (cell < next - 1) {
-			sectors += pgc->cell_playback[cell].last_sector - pgc->cell_playback[cell].first_sector + 1;
+		while( cell < next - 1 ) {
+			unsigned int secSize;
+			cell_playback_t * cell_playback = &pgc->cell_playback[cell];
+
+/* cell cannot index > nr_of_cells */
+			if( cell >= pgc->nr_of_cells )	break;
+
+			secSize	= cell_playback->last_sector - cell_playback->first_sector + 1;
+#if IGNORE_ANGLE
+			if( cell_playback->block_type == 1  ) { /* Angle block start */
+				unsigned int start = cell_playback->first_sector;
+				unsigned int end;
+
+				while( cell_playback->block_type == 1 && cell_playback->block_mode != 3 ) {
+					cell++;
+					cell_playback = &pgc->cell_playback[cell];
+				}
+				end = cell_playback->last_sector;
+				secSize = end - start + 1;
+				sectors += secSize;
+				goto ignore;
+			}
+#endif
+			sectors += secSize;
+#if IGNORE_ANGLE
+ignore:;
+#endif
 			cell++;
 		}
 		total += sectors;
-		if ((i + 1) == chapitre )	return( sectors );
+		if ((i + 1) == chapitre ) {
+			return( sectors );
+		}
 	}
 	return( total );
 }
