@@ -17,6 +17,12 @@ COMMENTAIRE :
 #include <stdlib.h>
 #include <stdint.h>
 #include <errno.h>
+#include <string.h>
+
+#ifdef __APPLE__
+/* fopen is 64-bit aware on Mac OS X */
+#define fopen64(A,B) fopen(A,B)
+#endif
 
 #define __IN_DVDINFO__
 #include "dvdinfo.h"
@@ -70,12 +76,6 @@ char * title;
 	FILE * fp;
 	int i;
 
-/* fake for tests */
-//	if( strncmp( device, "/dev", 4 ) ) {
-//		strcpy( title,"FAKE_TITLE" );
-//		return( 0 );
-//	}
-
 	fp = fopen64( device, "r" );
 	if( !fp ) {
 		fprintf(stderr,"%s: seek error %d\n", __FUNCTION__, errno );
