@@ -11,28 +11,33 @@ COMMENTAIRE :
 ================================================================================
 
 ==============================================================================*/
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdint.h>
+#include <stdlib.h>
 #include <string.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
 #include <sys/stat.h>
 
 #define CTEST(x)		/***/
+#define CTEST2(x)		/***/
 
 #include "dvdinfo.h"
 #include "dvdtools.h"
-
-static int BadStart = -1;
-static int BadEnd = -1;
+#include "globals.h"
+#include "ac.h"
+#include "badsect.h"
 
 static double FramesPerSec[4] = { -1.0, 25.00, -1.0, 29.97 };
-static char * _AudioFormat[7] = { "ac3", "?", "mpeg1", "mpeg2", "lpcm ", "sdds ", "dts" };
+static char * _AudioFormat[7] = { "ac3", "?", "mpeg1", "mpeg2", "lpcm", "sdds ", "dts" };
 
 #define MAX_PISTE		100
 static Piste_t	Pistes[MAX_PISTE];
 
+
 /*------------------------------------------------------------------------------
 	MILLISECONDE-
 Linux!jef 2005/12/16 00:10:15
@@ -51,6 +56,7 @@ int MilliSeconde( dvd_time_t * dt )
 
 	return( ms );
 }
+
 /*------------------------------------------------------------------------------
 	ISNAVPACK-
 Linux!jef 2006/01/05 21:47:00
@@ -193,6 +199,7 @@ char * BuildChapitreString( int noPisteVideo )
 	char * chapitreStr;
 	long long milliSec = 0;
 
+// fprintf(stderr,"Il y a %d chapitre\n", nbChapters );
 	chapitreStr = malloc( (nbChapters * 15)+1);
 	strcpy( chapitreStr, "00:00:00.000" );
 	cell = 0;
@@ -215,6 +222,7 @@ char * BuildChapitreString( int noPisteVideo )
 			strcat( chapitreStr, szDummy);
 		}
 	}
+// fprintf(stderr,"BuildChapitreString(%s)\n", chapitreStr );
 	return( chapitreStr );
 }
 
@@ -297,96 +305,31 @@ char * AudioFormat( int noPisteVideo, int noPisteAudio )
 	return( _AudioFormat[audio_attr->audio_format] );
 }
 
-
 /*------------------------------------------------------------------------------
-	FINDNEXTGOODSECTOR-
-Linux!jef 2006/07/07 20:49:13
-------------------------------------------------------------------------------*/
-
-static int FindNextGoodSector( dvd_file_t * dvdFile, int noSect, int lim )
-{
-	char buffer[DVD_VIDEO_LB_LEN];
-	int bMax;
-	int next;
-	int res;
-
-	if( lim < 1000 )	lim = 1000;
-	bMax = noSect + lim;
-
-	fprintf(stderr,"Testing <%d,%d>\n", noSect, bMax );
-	while( (bMax - noSect) > 1 ) {
-		next = noSect + (( bMax - noSect ) / 2);
-
-		res = DVDReadBlocks( dvdFile, next, 1, (unsigned char *)buffer );
-		if( res == 1 ) {
-			fprintf(stderr,"sector %d good\n", next );
-			bMax = next;
-		}
-		else {
-			fprintf(stderr,"sector %d bad\n", next );
-			noSect = next;
-		}
-	}
-	fprintf(stderr,"NextGood: %d\n", bMax );
-	return( bMax );
-}
-
-/*------------------------------------------------------------------------------
-	MYDVDREADBLOCKS-
+	MYDVDREAD1BLOCK-
 Linux!jef 2006/07/06 22:04:04
+	Special for dvd errors handling
 ------------------------------------------------------------------------------*/
-
-ssize_t MyDVDReadBlocks( dvd_file_t * dvdFile, int noSect, size_t nbSect, unsigned char * buffer )
+int MyDVDRead1Block( dvd_file_t * dvdFile, int noSect, void * buffer )
 {
 	ssize_t nbRead;
 
-	if( (noSect >= BadStart) && (int)(noSect+nbSect) <= BadEnd ) {
-		memset( buffer, 0, DVD_VIDEO_LB_LEN * nbSect );
-		return( nbSect );
-	}
-	nbRead = DVDReadBlocks( dvdFile, noSect, nbSect, buffer );
-	if( nbRead < 0 ) {
-		nbRead = 0;
-	}
-	else {
-		BadStart = BadEnd = -1;
-	}
-	noSect += nbRead;
-	nbSect -= nbRead;
-	buffer += ( nbRead * DVD_VIDEO_LB_LEN );
-	if( !nbSect )	return( nbRead );
-	fprintf(stderr,"ReadError: nbSect=%d\n", nbSect );
-/* En cas d'erreur de  lecture on suppose que c'est un plage complete qui est HS pour eviter
-	de prendre trop de temps avec des lectures unitaires
-*/
-	BadStart = noSect;
-	BadEnd = FindNextGoodSector( dvdFile, noSect, nbSect + 1 );
-
-	return( nbRead + MyDVDReadBlocks( dvdFile, noSect, nbSect, buffer ) );
-#if 0
-
-	if( nbSect == 1 ) {
-		memset( buffer, 0, DVD_VIDEO_LB_LEN );
-		return( 1 );
-	}
-	while( nbSect > 0 ) {
-		ssize_t res;
-
-		res = DVDReadBlocks( dvdFile, noSect, 1, buffer );
-		if( res != 1 ) {
-fprintf(stderr,"ReadError: Sector=%d zeroed\n", noSect );
-			memset( buffer, 0, DVD_VIDEO_LB_LEN );
-		}
-		else {
-fprintf(stderr,"ReadError: Sector=%d readed\n", noSect );
-		}
-		noSect += 1;
-		nbSect -= 1;
-		buffer += ( 1 * DVD_VIDEO_LB_LEN );
-		nbRead += 1;
-	}
-	return( nbRead );
+	CTEST2(fprintf(stderr,"%s: Reading(%d) at %p\n", __FUNCTION__, noSect, buffer ););
+#if MNG_BADSECTORS
+	if( IsBadSector( noSect ) )	return( 0 );
 #endif
+	nbRead = DVDReadBlocks( dvdFile, noSect, 1, buffer );
+	CTEST2(fprintf(stderr,"%s: Readed:=%ld\n", __FUNCTION__, nbRead ););
+	if( nbRead != 1 ) {
+		DBG('b',fprintf(stderr,"%s: bad sector: %d\n", __FUNCTION__, noSect ););
+		NoteBadSector( noSect );
+		if( IgnoreErrors == -1 ) {
+			IgnoreErrors = 1;
+		}
+		if( IgnoreErrors )	return( 0 );
+		return( -1 );
+	}
+	return( 1 );
 }
 
 /*------------------------------------------------------------------------------
@@ -407,3 +350,127 @@ void RazPistes()
 {
 	memset( &Pistes, 0, sizeof(Pistes));
 }
+/*------------------------------------------------------------------------------
+	CREATEDUMMYPACK-
+Linux!jef 2007/08/16 00:41:38
+------------------------------------------------------------------------------*/
+
+void CreateDummyPack( unsigned char * buffer )
+{
+	int8_t *ptr = (int8_t*)buffer;
+#pragma pack(1)
+ 	uint8_t dummy_pack [] =
+        {
+            /* pack header: SCR=0, mux rate=10080000bps, stuffing length=0 */
+            0, 0, 1, 0xba, 0x44, 0x00, 0x04, 0x00, 0x04, 0x01, 0x01, 0x89, 0xc3, 0xf8,
+            /* PES header for dummy video packet */
+            0, 0, 1, 0xe0, 0x07, 0xec, 0x81, 0x00, 0x00
+        };
+#pragma pack()
+ 	tc_memcpy( ptr, dummy_pack, sizeof (dummy_pack));
+ 	ptr += sizeof (dummy_pack);
+	memset( ptr, 0xff, DVD_VIDEO_LB_LEN - sizeof (dummy_pack));
+}
+
+/*------------------------------------------------------------------------------
+	CREATEDUMMYNAVPACK-
+Linux!jef 2007/08/16 00:43:54
+------------------------------------------------------------------------------*/
+
+void CreateDummyNavPack( unsigned char * buffer, unsigned int sector )
+{
+	int8_t *ptr = (int8_t*)buffer;
+	dsi_t dsiPack;
+	pci_t pciPack;
+#pragma pack(1)
+	static uint8_t nav_pack1 [] =
+	{
+	    /* pack header: SCR=0, mux rate=10080000bps, stuffing length=0 */
+	    0, 0, 1, 0xba, 0x44, 0x00, 0x04, 0x00, 0x04, 0x01, 0x01, 0x89, 0xc3, 0xf8,
+	    /* system header length=0x12=18*/
+	    0, 0, 1, 0xbb, 0x00, 0x12,
+	    /* contents of system header filled in at run time (18 bytes) */
+	    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	    /* PES header for first private stream 2 packet */
+	    0, 0, 1, 0xbf, 0x03, 0xd4
+	  };
+	static uint8_t nav_pack2 [] =
+	{
+	    /* PES header for second private stream 2 packet */
+	    0, 0, 1, 0xbf, 0x03, 0xfa
+	};
+#pragma pack()
+	tc_memcpy( ptr, nav_pack1, sizeof (nav_pack1));
+	ptr += sizeof (nav_pack1);
+	memset( ptr, 0, DVD_VIDEO_LB_LEN/2 - sizeof (nav_pack1));
+	ptr = (int8_t*)buffer + DVD_VIDEO_LB_LEN/2;
+	tc_memcpy( ptr, nav_pack2, sizeof (nav_pack2));
+	ptr += sizeof (nav_pack2);
+	memset( ptr, 0, DVD_VIDEO_LB_LEN/2 - sizeof (nav_pack2));
+
+	navRead_DSI( &dsiPack, buffer + DSI_START_BYTE);
+	navRead_PCI( &pciPack, buffer+0x2d);
+	dsiPack.dsi_gi.nv_pck_lbn= sector;
+	dsiPack.dsi_gi.vobu_ea = 1;
+
+	navRead_DSI((dsi_t*)(buffer + DSI_START_BYTE),(unsigned char*)&dsiPack);
+	pciPack.pci_gi.nv_pck_lbn = dsiPack.dsi_gi.nv_pck_lbn;
+	navRead_PCI((pci_t*)(buffer+0x2d),(unsigned char*)&pciPack);
+}
+/*------------------------------------------------------------------------------
+	VERIFNAVPACK-
+Linux!jef 2007/08/22 22:35:53
+------------------------------------------------------------------------------*/
+
+int VerifNavPack( unsigned char * p )
+{
+	int32_t        bMpeg1 = 0;
+	uint32_t       nHeaderLen;
+	uint32_t       nPacketLen;
+	uint32_t       nStreamID;
+
+	if (p[3] == 0xBA) { /* program stream pack header */
+		int32_t nStuffingBytes;
+
+		bMpeg1 = (p[4] & 0x40) == 0;
+
+		if (bMpeg1) {
+			p += 12;
+		} else { /* mpeg2 */
+			nStuffingBytes = p[0xD] & 0x07;
+			p += 14 + nStuffingBytes;
+		}
+	}
+
+	if (p[3] == 0xbb) { /* program stream system header */
+		nHeaderLen = (p[4] << 8) | p[5];
+		p += 6 + nHeaderLen;
+	}
+
+/* we should now have a PES packet here */
+	if (p[0] || p[1] || (p[2] != 1)) {
+		fprintf(stderr, "%s: demux error! %02x %02x %02x (should be 0x000001) \n",__FUNCTION__,p[0],p[1],p[2]);
+		return( 0 );
+	}
+
+	nPacketLen = p[4] << 8 | p[5];
+	nStreamID  = p[3];
+
+	nHeaderLen = 6;
+	p += nHeaderLen;
+
+	if (nStreamID == 0xbf) { /* Private stream 2 */
+//		if(p[0] == 0x00)	navRead_PCI(nav_pci, p+1);
+		p += nPacketLen;
+	/* We should now have a DSI packet. */
+		if(p[6] == 0x01) {
+			nPacketLen = p[4] << 8 | p[5];
+			p += 6;
+//			navRead_DSI(nav_dsi, p+1);
+		}
+		return( 1 );
+	}
+	fprintf(stderr,"%s: bad streamid 0x%x\n", __FUNCTION__, nStreamID );
+	return( 0 );
+}
+
