@@ -49,14 +49,12 @@ enum {
 
 
 enum {
-	PHASE2_ARRIERE = 0,
+	PHASE2_ARRIERE = 1,
 	PHASE2_AVANCER
 };
 
-/* Quand enclaencher l'analyse dymique */
-#define DYNQUAL_PCT		0.01 //	0.10
-
 #ifdef __NEED_GLOBALS__
+GtkWidget * MainDlg;
 int UserStopF = 0;
 int UserPauseF = 0;
 char DbgLevels[256] = { 0 };
@@ -64,6 +62,7 @@ int IgnoreErrors = -1;
 int Phase2 = 0;
 char Device[1024];
 char * TargetDir;
+int ImageReadyF = 0;
 #else
 extern int UserStopF;
 extern int UserPauseF;
@@ -72,8 +71,11 @@ extern int IgnoreErrors;
 extern int Phase2;
 extern char Device[1024];
 extern char * TargetDir;
+extern int ImageReadyF;
 #endif
 
+#define PPM_FILE	"/tmp/dvd95.ppm"
+
 #define DBG( lvl, x )		if( lvl < 0 || DbgLevels[lvl] ) x
 #define IsLevelSet( lvl )	(DbgLevels[lvl])
 
