@@ -470,7 +470,7 @@ insertHomeDir (char * szDir);
 
 // Sound abspielen
 void 
-play_sound_if_ready ();
+play_sound_if_ready (char * lxdvdrip_wav_name);
 
 
 // Liefert Requantisierungsfaktor zurueck
