@@ -498,14 +498,14 @@ static MINLINE void flush_write_buffer()
 
 /////---- begin ext mpeg code
 
-const uint8 non_linear_mquant_table[32] =
+static const uint8 non_linear_mquant_table[32] =
 {
 	0, 1, 2, 3, 4, 5, 6, 7,
 	8,10,12,14,16,18,20,22,
 	24,28,32,36,40,44,48,52,
 	56,64,72,80,88,96,104,112
 };
-const uint8 map_non_linear_mquant[113] =
+static const uint8 map_non_linear_mquant[113] =
 {
 	0,1,2,3,4,5,6,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,
 	16,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,22,22,
@@ -637,7 +637,7 @@ static MINLINE int isNotEmpty(RunLevel *blk)
 #include "putvlc.h"
 
 // return != 0 if error
-int putAC(int run, int signed_level, int vlcformat)
+static int putAC(int run, int signed_level, int vlcformat)
 {
 	int level, len;
 	const VLCtable *ptab = NULL;
@@ -699,7 +699,7 @@ static MINLINE int putACfirst(int run, int val)
 	else return putAC(run,val,0);
 }
 
-void putnonintrablk(RunLevel *blk)
+static void putnonintrablk(RunLevel *blk)
 {
 	assert(blk->level);
 
@@ -1773,7 +1773,7 @@ do {															\
     }															\
 } while (0)
 
-void putmbdata(int macroblock_modes)
+static void putmbdata(int macroblock_modes)
 {
 		putmbtype(macroblock_modes & 0x1F);
 
@@ -1931,7 +1931,7 @@ static MINLINE int slice_init (int code)
 
 }
 
-void mpeg2_slice ( const int code )
+static void mpeg2_slice ( const int code )
 {
 #define bit_buf (inbitbuf)
 
@@ -2197,7 +2197,7 @@ skip_mb:
 	#endif
 #endif
 
-int quantisers[42] =
+static int quantisers[42] =
 {
 	1, 2, 3, 4, 5, 6, 7, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32,
 	34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 60, 62, 64, 72, 80,
@@ -2757,6 +2757,7 @@ void requant_initvar()
 /*------------------------------------------------------------------------------
 	REQUANT_SETFACTOR-
 Linux!jef 2006/11/09 21:58:44
+	Recompute requant tables
 ------------------------------------------------------------------------------*/
 
 void requant_factorchange()
