@@ -13,20 +13,40 @@ COMMENTAIRE :
 ==============================================================================*/
 #define __USE_LARGEFILE64
 #define _LARGEFILE64_SOURCE
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 #include <stdio.h>
 #include <stdlib.h>
-#include <stdint.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/statfs.h>
+#if defined(__sun)
+#	include <sys/statvfs.h>
+#	include <sys/ioctl.h>
+#else
+#	include <sys/statfs.h>
+#endif
 #include <fcntl.h>
 #include <unistd.h>
+#if defined(__sun)
+#	include <stropts.h>
+#endif
 #include <string.h>
 #include <errno.h>
 #include <sys/wait.h>
-#include <linux/cdrom.h>
+#if defined(__sun)
+#	include <sys/cdio.h>
+#	define NON_BLOCKING
+#else
+#	include <linux/cdrom.h>
+#	include <linux/loop.h>
+#endif
 #include <ctype.h>
 
+
+#include <limits.h>
+
+
 char ** environ;
 #define	SH_PATH	"/bin/sh"
 #define	SH_NAME	"sh"
@@ -158,6 +178,17 @@ Linux!jef 2005/12/19 20:57:02
 
 long long FsFree( char * fsName )
 {
+#if defined(__sun)
+        struct statvfs b;
+	int res;
+	long long freeSize;
+
+        res = statvfs( fsName, &b);
+	if( res < 0 )	return( 0LL );
+	freeSize = ((long long)b.f_bavail * (long long)b.f_bsize);
+
+	return( freeSize );
+#else
 	struct statfs b;
 	int res;
 	long long freeSize;
@@ -165,7 +196,9 @@ long long FsFree( char * fsName )
 	res = statfs( fsName, &b );
 	if( res < 0 )	return( 0LL );
 	freeSize = ((long long)b.f_bavail * (long long)b.f_bsize);
+// fprintf(stderr,"avail: %ld bsize: %ld = %lld\n", b.f_bavail,  b.f_bsize, freeSize );
 	return( freeSize );
+#endif
 }
 /*------------------------------------------------------------------------------
 	DIREXIST-
@@ -432,6 +465,9 @@ int IsDvdLoaded( char * device )
 	int fd;
 	int ret;
 	struct stat64 b;
+#if !defined(__sun)
+	struct loop_info lInfo;
+#endif
 
 // fprintf(stderr,"%s(%s)\n", __FUNCTION__, device );
 	if( stat64( device, &b) ) {
@@ -444,13 +480,25 @@ int IsDvdLoaded( char * device )
 // perror( "open" );
 		return( -1 );
 	}
+#if defined (__sun)
+        struct cdrom_tochdr cdth;
+        ret = ioctl( fd, CDROMREADTOCHDR, &cdth);
+        if( cdth.cdth_trk1 > 0 ) {
+#else
 	ret = ioctl( fd,  CDROM_DRIVE_STATUS, CDSL_CURRENT);
-	close( fd );
-	if( ret == -1 ) {
-// perror( "ioctl" );
-		return( -1 );
+	if( ret == CDS_DISC_OK ) {
+#endif
+		close( fd );
+		return( 1 );
 	}
-	if( ret == CDS_DISC_OK )	return( 1 );
+#if !defined(__sun)
+/* Try to know if it is a loop device */
+	ret = ioctl( fd, LOOP_GET_STATUS, &lInfo );
+	close( fd );
+	if( !ret )	return( 1 );
+#else
+	close( fd );
+#endif
 	return( 0 );
 }
 /*------------------------------------------------------------------------------
@@ -477,4 +525,25 @@ int StringDuree2Sec( char * string )
 	}
 	return( sec );
 }
+/*------------------------------------------------------------------------------
+	ISLOOPDEVICEREADY-
+Linux!jef 2007/02/12 20:55:27
+------------------------------------------------------------------------------*/
+
+int IsLoopDeviceReady( char * loopDevice )
+{
+#if !defined(__sun)
+	struct loop_info lInfo;
+	int fd;
+	int ret;
+
+	fd = open( loopDevice, O_RDONLY | O_NONBLOCK);
+	if( fd < 0 )	return( 0 );
+	ret = ioctl( fd, LOOP_GET_STATUS, &lInfo );
+// fprintf(stderr,"(%s)=%d lInfo.lo_name(%s)\n", loopDevice, ret,lInfo.lo_name );
+	close( fd );
+	if( !ret )	return( 1 );
+#endif
+	return( 0 );
+}
 
