@@ -20,6 +20,9 @@
 // Revision history (latest first):
 //
 //
+// 2007/01/26: V0.99.3: Fixed assumptions in lock() which do not hold for pipes.
+//                      This cures the "Premature EOF" problem.
+//
 // 2006/04/15: V0.99.2: Fixed some signed/unsigned issues which caused compiler
 //                      warnings on some platforms. No funtional changes.
 //
@@ -27,8 +30,6 @@
 //                      play_cell when it encounters a cell gap. This enables
 //                      proper evaporation of some strangely authored DVDs.
 //
-// 19.02.2006, Stefan Becker, tc_memcpy aus Transcode
-//
 // 19.02.2006, Stefan Becker, Vamps 0.99.1 Anpassungen
 //
 // 2006/02/14: V0.99: Usage of inttypes.h. No functional changes (however,
@@ -88,8 +89,6 @@
 #include <inttypes.h>
 #include <sys/stat.h>
 
-#include "ac.h"
-
 
 // DVD sector size
 #define SECT_SIZE 2048
@@ -217,9 +216,6 @@ main (int argc, char *const argv [])
 
   opterr = 1;
 
-  ac_mmtest();
-  tc_memcpy_init( 0, ac_mmflag());
-
   while ((c = getopt_long_only (argc, argv, "a:s:e:E:puvi:pS:",
 				long_options, NULL)) >= 0)
   {
@@ -338,8 +334,8 @@ main (int argc, char *const argv [])
   // print this run's statistics if wanted
   if (verbose >= 1)
   {
-    fprintf (stderr, "Info: Total bytes read: %llu\n", bytes_read);
-    fprintf (stderr, "Info: Total bytes written: %llu\n", bytes_written);
+    fprintf (stderr, "Info: Total bytes read: %llu\n", (long long)bytes_read);
+    fprintf (stderr, "Info: Total bytes written: %llu\n", (long long)bytes_written);
     fprintf (stderr, "Info: Total sequence headers in video stream: %d\n",
 	     sequence_headers);
     fprintf (stderr,
@@ -347,22 +343,22 @@ main (int argc, char *const argv [])
 	     nav_packs);
     fprintf (stderr,
 "Info: Total bytes vaporized in audio and subpicture streams: %llu (%.2f%%)\n",
-	     (uint64_t) skipped_aux_packs * SECT_SIZE,
+	     (long long)(uint64_t) skipped_aux_packs * SECT_SIZE,
 	     (double) skipped_aux_packs /
 	     (double) (bytes_read / SECT_SIZE) * 100.0);
     fprintf (stderr,
 	     "Info: Total bytes vaporized in cell gaps: %llu (%.2f%%)\n",
-	     (uint64_t) cell_gap_packs * SECT_SIZE,
+	     (long long)(uint64_t) cell_gap_packs * SECT_SIZE,
 	     (double) cell_gap_packs /
 	     (double) (bytes_read / SECT_SIZE) * 100.0);
     fprintf (stderr,
 	     "Info: Total bytes vaporized in video stream: %llu (%.2f%%)\n",
-	     (uint64_t) skipped_video_packs * SECT_SIZE,
+	     (long long)(uint64_t) skipped_video_packs * SECT_SIZE,
 	     (double) skipped_video_packs /
 	     (double) (bytes_read / SECT_SIZE) * 100.0);
     fprintf (stderr,
 	     "Info: Total padding bytes in video stream: %llu (%.2f%%)\n",
-	     padding_bytes,
+	     (long long)padding_bytes,
 	     (double) padding_bytes / (double) bytes_written * 100.0);
     fprintf (stderr, "Info: Total vaporization factor: %.3f\n",
 	     (double) bytes_read / (double) bytes_written);
@@ -405,7 +401,7 @@ scan_track_map (int *map, unsigned ntracks)
 static inline int
 lock (int size)
 {
-  int avail, n;
+  int avail, n=0;
 
   avail = rhwp - rptr;
 
@@ -414,18 +410,29 @@ lock (int size)
 
   if (avail)
   {
-    tc_memcpy (rbuf, rptr, avail);
+    memcpy (rbuf, rptr, avail);
     rptr = rbuf;
     rhwp = rptr + avail;
   }
 
-  n = read (0, rhwp, RBUF_SIZE - avail);
-
-  if (n % SECT_SIZE)
-    fatal ("Premature EOF");
-
-  rhwp       += n;
-  bytes_read += n;
+  while (avail < size)  
+  {
+    // read; reads from an open pipe will return any non-zero amount of data
+    //       (not necessarily the amount we wanted!)
+    n = read (0, rhwp, RBUF_SIZE - avail);
+    if (!n)
+    {
+      if (avail % SECT_SIZE)
+        // we got an EOF and only a partial sector
+        fatal ("Premature EOF");
+      break;
+    }
+    else if (n == -1)
+      fatal ("Read from stdin: %s", strerror (errno));
+    rhwp       += n;
+    bytes_read += n;
+    avail      += n;
+  }
 
   return !n;
 }
@@ -441,7 +448,7 @@ copy (int size)
   if ((wptr - wbuf) + size > WBUF_SIZE)
     fatal ("Write buffer overflow");
 
-  tc_memcpy (wptr, rptr, size);
+  memcpy (wptr, rptr, size);
   rptr += size;
   wptr += size;
 }
@@ -607,7 +614,7 @@ requant (uint8_t *dst, uint8_t *src, int n, float fact)
   int rv;
 
   // this ensures for the requant thread to stop at this GOP's end
-  tc_memcpy (src + n, "\0\0\1", 3);
+  memcpy (src + n, "\0\0\1", 3);
 
   pthread_mutex_lock (&mutr);
 
@@ -686,7 +693,7 @@ new_private_1_type (uint8_t *ptr)
   }
   else
   {
-    fprintf (stderr, "Unknown private stream 1 type at %llu: %02x\n", rtell (ptr), type);
+    fprintf (stderr, "Unknown private stream 1 type at %llu: %02x\n", (long long)rtell (ptr), type);
     fprintf (stderr, "no break, dont copy this track\n");
     return 0;
   }
@@ -774,7 +781,7 @@ static void
 vap_leader (void)
 {
   uint8_t *ptr;
-  int      id, data_length;
+  int      id;
 
   while (!lock (SECT_SIZE))
   {
@@ -958,7 +965,7 @@ vap_phase1 (void)
 	}
 
 	//fprintf (stderr, "data_length=%d\n", data_length);
-	tc_memcpy (viptr, ptr + 6 + opt_length, data_length);
+	memcpy (viptr, ptr + 6 + opt_length, data_length);
 	viptr += data_length;
 	break;
 
@@ -1035,7 +1042,7 @@ gen_video_packet (uint8_t *ptr, uint8_t *voptr, int avail)
   if (avail >= data_length)
   {
     // write out a full video packet (usually 2025 byte)
-    tc_memcpy (ptr + 6 + 3 + header_data_length, voptr, data_length);
+    memcpy (ptr + 6 + 3 + header_data_length, voptr, data_length);
     ptr [4] = (SECT_SIZE - (14 + 6)) >> 8;
     ptr [5] = (SECT_SIZE - (14 + 6)) & 0xff;
     ptr [8] = header_data_length;
@@ -1046,7 +1053,7 @@ gen_video_packet (uint8_t *ptr, uint8_t *voptr, int avail)
   if (avail < data_length - 6)
   {
     // write a short video packet and a padding packet
-    tc_memcpy (ptr + 6 + 3 + header_data_length, voptr, avail);
+    memcpy (ptr + 6 + 3 + header_data_length, voptr, avail);
     ptr [4] = (3 + header_data_length + avail) >> 8;
     ptr [5] =  3 + header_data_length + avail;
     ptr [8] = header_data_length;
@@ -1073,7 +1080,7 @@ gen_video_packet (uint8_t *ptr, uint8_t *voptr, int avail)
   padding_bytes += padding_length;
   memset (ptr + 6 + 3 + header_data_length, 0xff, padding_length);
   header_data_length += padding_length;
-  tc_memcpy (ptr + 6 + 3 + header_data_length, voptr, avail);
+  memcpy (ptr + 6 + 3 + header_data_length, voptr, avail);
   ptr [4] = (SECT_SIZE - (14 + 6)) >> 8;
   ptr [5] = (SECT_SIZE - (14 + 6)) & 0xff;
   ptr [8] = header_data_length;
@@ -1090,7 +1097,7 @@ gen_video_packet (uint8_t *ptr, uint8_t *voptr, int avail)
 static inline void
 vap_phase2 (int seq_length)
 {
-  int      i, id, avail, data_length;
+  int      i, id, avail;
   uint8_t *ptr, *voptr = vobuf, *vohwp = vobuf + volen;
 
   for (i = 0; i < seq_length; i += SECT_SIZE)
@@ -1236,7 +1243,7 @@ vaporize (void)
     else
     {
       // don't do requantization
-      tc_memcpy (vobuf, vibuf, vilen);
+      memcpy (vobuf, vibuf, vilen);
       volen = vilen;
     }
 
