@@ -201,7 +201,6 @@ pthread_mutex_t mutw  = PTHREAD_MUTEX_INITIALIZER;
 extern "C" {
 #endif
 static void _VarInit PROTO((void));
-static void scan_track_map PROTO((int *map, int ntracks));
 static void flush PROTO((void));
 static void vap_leader PROTO((void));
 static void vap_trailer PROTO((int length));
@@ -1052,7 +1051,11 @@ vap_phase1 (void)
 	  {
 	    sequence_headers++;
 	    vilen = viptr - vibuf;
-
+            /* Weird MPEG2 STREAMS */
+            if( !vilen ) {
+	      eof = 1;
+              return seq_length;
+            }
 	    return seq_length;
 	  }
 	}
