@@ -19,7 +19,7 @@ COMMENTAIRE :
 #ifdef __cplusplus
 extern "C" {
 #endif
-int VaporizeInit PROTO((int (*readFun)(), int (*writeFun)()));
+int VaporizeInit PROTO((int (*readFun)(), int (*writeFun)(), int preserveF ));
 int VaporizeAudio PROTO((int audioTrack));
 int VaporizeSubp PROTO((int subpTrack));
 int VaporizeFactor PROTO((double factor, int dynF ));
